import * as React from 'react';
import { delegateCombine, delegateRemove } from "igniteui-react-core/ES2015/type";
import { SliceClickEventArgs } from "./igr-slice-click-event-args";
import { HoleDimensionsChangedEventArgs } from "./igr-hole-dimensions-changed-event-args";
import { XamDoughnutChart } from "./XamDoughnutChart";
import { getModifiedProps, isValidProp, ensureBool, fromPoint } from "igniteui-react-core/ES2015/componentUtil";
import { Style } from "igniteui-react-core/ES2015/Style";
/**
 * Represents concentric circles divided on arcs  depending on data.
*/
export class IgrDoughnutChart extends React.Component {
    constructor(props) {
        super(props);
        this._sliceClick = null;
        this._sliceClick_wrapped = null;
        this._holeDimensionsChanged = null;
        this._holeDimensionsChanged_wrapped = null;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    createImplementation() {
        return new XamDoughnutChart();
    }
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    componentDidMount() {
        for (const p of Object.keys(this.props)) {
            if (isValidProp(this, p)) {
                this[p] = this.props[p];
            }
        }
    }
    shouldComponentUpdate(nextProps, nextState) {
        const mod = getModifiedProps(this.props, nextProps);
        for (const p of Object.keys(mod)) {
            if (isValidProp(this, p)) {
                this[p] = mod[p];
            }
        }
        return true;
    }
    render() {
        return null;
    }
    /**
     * Gets or sets whether the slices can be selected.
    */
    get allowSliceSelection() {
        return this.i.aw;
    }
    set allowSliceSelection(v) {
        this.i.aw = ensureBool(v);
    }
    /**
     * Gets or sets whether all surface interactions with the plot area should be disabled.
    */
    get isSurfaceInteractionDisabled() {
        return this.i.ax;
    }
    set isSurfaceInteractionDisabled(v) {
        this.i.ax = ensureBool(v);
    }
    /**
     * Gets or sets whether the slices can be exploded.
    */
    get allowSliceExplosion() {
        return this.i.av;
    }
    set allowSliceExplosion(v) {
        this.i.av = ensureBool(v);
    }
    /**
     * Gets or sets the inner extent of the doughnut chart. It is percent from the outer ring's radius.
    */
    get innerExtent() {
        return this.i.a3;
    }
    set innerExtent(v) {
        this.i.a3 = +v;
    }
    /**
     * Gets or sets the fill brush.
    */
    get selectedSliceFill() {
        return this.i.ce ? this.i.ce.fill : null;
    }
    set selectedSliceFill(v) {
        this.ensureSelectedStyle();
        this.i.ce.fill = v;
    }
    /**
     * Gets or sets the stroke brush.
    */
    get selectedSliceStroke() {
        return this.i.ce ? this.i.ce.stroke : null;
    }
    set selectedSliceStroke(v) {
        this.ensureSelectedStyle();
        this.i.ce.stroke = v;
    }
    /**
     * Gets or sets the stroke thickness.
    */
    get selectedSliceStrokeThickness() {
        return this.i.ce ? this.i.ce.strokeThickness : NaN;
    }
    set selectedSliceStrokeThickness(v) {
        this.ensureSelectedStyle();
        this.i.ce.strokeThickness = +v;
    }
    /**
     * Gets or sets the opacity.
    */
    get selectedSliceOpacity() {
        return this.i.ce ? this.i.ce.opacity : NaN;
    }
    set selectedSliceOpacity(v) {
        this.ensureSelectedStyle();
        this.i.ce.opacity = +v;
    }
    ensureSelectedStyle() {
        if (this.i.ce) {
            return;
        }
        this.i.ce = new Style();
    }
    /**
     * Gets or sets the scaling value used to affect the pixel density of the control.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
     * to appear blurry.
    */
    get pixelScalingRatio() {
        return this.i.a4;
    }
    set pixelScalingRatio(v) {
        this.i.a4 = +v;
    }
    /**
     * Resolved pixel scaling ratio. Unless explicitly overridden by the IgxDoughnutChart.PixelScalingRatioComponent property,
     * this one returns the default ratio enforced by device. High resolution devices will initialize this property
     * to a higher value.
    */
    get actualPixelScalingRatio() {
        return this.i.a1;
    }
    set actualPixelScalingRatio(v) {
        this.i.a1 = +v;
    }
    /**
     * Used to notify the control that the control is no longer needed and can release any resources.
    
    */
    destroy() {
        this.i.destroy();
    }
    /**
     * Called by the UI framework to provide a UI container for rendering this control.
    
    * @param container  * The UI container element.
    */
    provideContainer(container) {
        this.i.provideContainer(container);
    }
    /**
     * Called when the control has been resized.
    
    */
    notifyResized() {
        this.i.notifyResized();
    }
    /**
     * Gets the ID of the UI container.
    
    */
    getContainerID() {
        let iv = this.i.bd();
        return (iv);
    }
    /**
     * Gets the center coordinates of the doughnut chart's center presenter.
    
    */
    getCenterCoordinates() {
        let iv = this.i.cd();
        return fromPoint(iv);
    }
    /**
     * Gets the hole radius of the doughnut chart's center presenter.
    
    */
    getHoleRadius() {
        let iv = this.i.a2();
        return (iv);
    }
    /**
     * Use to force the doughnut chart to finish any deferred work before printing or evaluating its visual.
     * This should only be called if the visual of the doughnut chart needs to be synchronously saved or evaluated.
     * Calling this method too often will hinder the performance of the doughnut chart.
    
    */
    flush() {
        this.i.bk();
    }
    /**
     * Returns the chart visuals expressed as a serialized string.
    
    */
    exportSerializedVisualData() {
        let iv = this.i.bc();
        return (iv);
    }
    notifyInsertItem(source_, index, newItem) {
        this.i.bm(source_, index, newItem);
    }
    notifySetItem(source_, index, oldItem, newItem) {
        this.i.bp(source_, index, oldItem, newItem);
    }
    /**
     * Used to manually notify the chart that the data source has reset or cleared its items.
    
    */
    notifyClearItems(source_) {
        this.i.bl(source_);
    }
    notifyRemoveItem(source_, index, oldItem) {
        this.i.bn(source_, index, oldItem);
    }
    /**
     * Raised when the slice is clicked.
    */
    get sliceClick() {
        return this._sliceClick;
    }
    set sliceClick(ev) {
        if (this._sliceClick !== null) {
            this.i.sliceClick = delegateRemove(this.i.sliceClick, this._sliceClick_wrapped);
            this._sliceClick_wrapped = null;
            this._sliceClick = null;
        }
        this._sliceClick = ev;
        this._sliceClick_wrapped = (o, e) => {
            let outerArgs = new SliceClickEventArgs();
            outerArgs._provideImplementation(e);
            this._sliceClick(this, outerArgs);
        };
        this.i.sliceClick = delegateCombine(this.i.sliceClick, this._sliceClick_wrapped);
    }
    /**
     * Raised when the dimensions (center point or radius) of the doughnut hole change.
    */
    get holeDimensionsChanged() {
        return this._holeDimensionsChanged;
    }
    set holeDimensionsChanged(ev) {
        if (this._holeDimensionsChanged !== null) {
            this.i.holeDimensionsChanged = delegateRemove(this.i.holeDimensionsChanged, this._holeDimensionsChanged_wrapped);
            this._holeDimensionsChanged_wrapped = null;
            this._holeDimensionsChanged = null;
        }
        this._holeDimensionsChanged = ev;
        this._holeDimensionsChanged_wrapped = (o, e) => {
            let outerArgs = new HoleDimensionsChangedEventArgs();
            outerArgs._provideImplementation(e);
            this._holeDimensionsChanged(this, outerArgs);
        };
        this.i.holeDimensionsChanged = delegateCombine(this.i.holeDimensionsChanged, this._holeDimensionsChanged_wrapped);
    }
}
