import { UnknownValuePlotting } from "igniteui-react-core/ES5/UnknownValuePlotting";
import { IgrHorizontalAnchoredCategorySeries, IIgrHorizontalAnchoredCategorySeriesProps } from "./igr-horizontal-anchored-category-series";
import { LineSeries } from "./LineSeries";
/**
 * Represents a IgxDataChartComponent line series.
 * Displays trend over time or ordered categories.Useful when there are many data points and the order is important.
*
* `IgxLineSeriesComponent` belongs to a group of `IgxLineSeriesComponent` and it is rendered using a collection of points connected by straight line segments.
*
* ```html
*  <igx-data-chart
*     [dataSource]="data">
*     <igx-category-x-axis
*         label="label"
*         #xAxis>
*     </igx-category-x-axis>
*     <igx-numeric-y-axis
*         #yAxis>
*     </igx-numeric-y-axis>
*     <igx-line-series
*         [xAxis]="xAxis"
*         [yAxis]="yAxis"
*         valueMemberPath="value">
*     </igx-line-series>
* </igx-data-chart>
* ```
*/
export declare class IgrLineSeries extends IgrHorizontalAnchoredCategorySeries<IIgrLineSeriesProps> {
    protected createImplementation(): LineSeries;
    readonly i: LineSeries;
    constructor(props: IIgrLineSeriesProps);
    /**
     * Gets whether the current series shows an area or line shape.
    *
    * Gets whether the `IgxLineSeriesComponent` shows an area or a line shape.
    */
    readonly isAreaOrLine: boolean;
    /**
     * Determines how unknown values will be plotted on the chart.
     * Null and Double.NaN are two examples of unknown values.
    *
    * Determines how unknown values will be plotted for the `IgxLineSeriesComponent`. This can be set to `IgxLineSeriesComponent` to create a continous shape or `IgxLineSeriesComponent` to create breaks in the series.
    *
    * Null and Double.NaN are two examples of unknown values.
    *
    * ```html
    * <igx-data-chart #chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-line-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         unknownValuePlotting="LinearInterpolate">
    *     </igx-line-series>
    * </igx-data-chart>
    * ```
    */
    unknownValuePlotting: UnknownValuePlotting;
}
export interface IIgrLineSeriesProps extends IIgrHorizontalAnchoredCategorySeriesProps {
    /**
     * Determines how unknown values will be plotted on the chart.
     * Null and Double.NaN are two examples of unknown values.
    *
    * Determines how unknown values will be plotted for the `IgxLineSeriesComponent`. This can be set to `IgxLineSeriesComponent` to create a continous shape or `IgxLineSeriesComponent` to create breaks in the series.
    *
    * Null and Double.NaN are two examples of unknown values.
    *
    * ```html
    * <igx-data-chart #chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-line-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         unknownValuePlotting="LinearInterpolate">
    *     </igx-line-series>
    * </igx-data-chart>
    * ```
    */
    unknownValuePlotting?: UnknownValuePlotting | string;
}
